# API Reference

This section contains the API Reference autogenerated directly from the docstrings of the code.

Throughout the reference there should be backlinks to the [`Learn`](../learn/index.md) sections that cover those specific modules, classes, methods, functions, etc.

There are two main sections of this reference:

- [`Core`](./core/index.md): The core functionality of Mirascope
- [`Integrations`](./integrations/index.md): Currently supported integrations.

We're always looking to improve the library, so if there are additional features or integrations you're interested in including in the library, let us know!
